@@ -108,18 +108,12 @@ spec = do
       , "Q"
       , unlines
           [ "Q -> [["
-          , "  org -> [["
-          , "    eolang -> [["
-          , "      bytes -> [["
-          , "        data -> ?,"
-          , "        @ -> $.data"
-          , "      ]],"
-          , "      number -> [["
-          , "        as-bytes -> ?,"
-          , "        @ -> $.as-bytes,"
-          , "        plus -> [[ x -> ?, L> L_org_eolang_number_plus ]]"
-          , "      ]]"
-          , "    ]]"
+          , "  bytes(data) -> [["
+          , "    @ -> $.data"
+          , "  ]],"
+          , "  number(as-bytes) -> [["
+          , "    @ -> $.as-bytes,"
+          , "    plus(x) -> [[ L> L_number_plus ]]"
           , "  ]],"
           , "  @ -> 5.plus(6)"
           , "]]"
@@ -131,19 +125,15 @@ spec = do
       , "Q"
       , unlines
           [ "Q -> [["
-          , "  org -> [["
-          , "    eolang -> [["
-          , "      bytes -> [["
-          , "        data -> ?,"
-          , "        @ -> $.data"
-          , "      ]],"
-          , "      number -> [["
-          , "        as-bytes -> ?,"
-          , "        @ -> $.as-bytes,"
-          , "        plus -> [[ x -> ?, L> L_org_eolang_number_plus ]],"
-          , "        times -> [[ x -> ?, L> L_org_eolang_number_times ]]"
-          , "      ]]"
-          , "    ]]"
+          , "  bytes -> [["
+          , "    data -> ?,"
+          , "    @ -> $.data"
+          , "  ]],"
+          , "  number -> [["
+          , "    as-bytes -> ?,"
+          , "    @ -> $.as-bytes,"
+          , "    plus -> [[ x -> ?, L> L_number_plus ]],"
+          , "    times -> [[ x -> ?, L> L_number_times ]]"
           , "  ]],"
           , "  @ -> $.c.times(1.8).plus(32),"
           , "  c -> 25"
@@ -156,20 +146,16 @@ spec = do
       , "Q"
       , unlines
           [ "Q -> [["
-          , "  org -> [["
-          , "    eolang -> [["
-          , "      bytes -> [["
-          , "        data -> ?,"
-          , "        @ -> $.data"
-          , "      ]],"
-          , "      number -> [["
-          , "        as-bytes -> ?,"
-          , "        @ -> $.as-bytes,"
-          , "        times -> [[ x -> ?, L> L_org_eolang_number_times ]],"
-          , "        plus -> [[ x -> ?, L> L_org_eolang_number_plus ]],"
-          , "        eq -> [[ x -> ?, y -> ?, L> L_org_eolang_number_eq ]]"
-          , "      ]]"
-          , "    ]]"
+          , "  bytes -> [["
+          , "    data -> ?,"
+          , "    @ -> $.data"
+          , "  ]],"
+          , "  number -> [["
+          , "    as-bytes -> ?,"
+          , "    @ -> $.as-bytes,"
+          , "    times -> [[ x -> ?, L> L_number_times ]],"
+          , "    plus -> [[ x -> ?, L> L_number_plus ]],"
+          , "    eq -> [[ x -> ?, y -> ?, L> L_number_eq ]]"
           , "  ]],"
           , "  fac -> [["
           , "    x -> ?,"
@@ -203,12 +189,8 @@ spec = do
       , "Q.x"
       , unlines
           [ "Q -> [["
-          , "  org -> [["
-          , "    eolang -> [["
-          , "      number(as-bytes) -> [[ @ -> as-bytes ]],"
-          , "      bytes(data) -> [[ @ -> data ]]"
-          , "    ]]"
-          , "  ]],"
+          , "  number(as-bytes) -> [[ @ -> as-bytes ]],"
+          , "  bytes(data) -> [[ @ -> data ]],"
           , "  x -> 5"
           , "]]"
           ]
